@@ -404,8 +404,8 @@ class Fleet:
             error_msg = f"Failed to create verifier {task_json.get('key', task_json.get('id'))}: {e}"
             if raise_on_verifier_error:
                 raise ValueError(error_msg) from e
-            else:
-                logger.warning(error_msg)
+            # else:
+            #     logger.warning(error_msg)
 
         task = Task(
             key=task_json.get("key", task_json.get("id")),
@@ -495,23 +495,23 @@ class Fleet:
                                 verifier_sha=tr.verifier.sha256,
                             )
                         except Exception as e:
-                            logger.warning(
-                                f"Failed to create verifier {tr.verifier.key}: {e}"
-                            )
+                            # logger.warning(
+                            #     f"Failed to create verifier {tr.verifier.key}: {e}"
+                            # )
                             return None
                     else:
                         # Fallback: try fetching by ID
                         try:
-                            logger.warning(
-                                f"Embedded verifier code missing for {tr.verifier.key} (NoSuchKey). "
-                                f"Attempting to refetch by id {tr.verifier.verifier_id}"
-                            )
+                            # logger.warning(
+                            #     f"Embedded verifier code missing for {tr.verifier.key} (NoSuchKey). "
+                            #     f"Attempting to refetch by id {tr.verifier.verifier_id}"
+                            # )
                             return self._load_verifier(tr.verifier.verifier_id)
                         except Exception as e:
-                            logger.warning(
-                                f"Refetch by verifier id failed for {tr.verifier.key}: {e}. "
-                                "Leaving verifier unset."
-                            )
+                            # logger.warning(
+                            #     f"Refetch by verifier id failed for {tr.verifier.key}: {e}. "
+                            #     "Leaving verifier unset."
+                            # )
                             return None
 
                 # Add the task for parallel execution
@@ -551,7 +551,7 @@ class Fleet:
                             result = future.result()
                             verifier_results.append(result)
                         except Exception as e:
-                            logger.warning(f"Verifier loading failed: {e}")
+                            # logger.warning(f"Verifier loading failed: {e}")
                             verifier_results.append(None)
 
         # Build tasks with results
@@ -638,10 +638,10 @@ class Fleet:
             with open(filename, "w", encoding="utf-8") as f:
                 json.dump(tasks_data, f, indent=2, default=str)
 
-            logger.info(f"Exported {len(tasks)} tasks to {filename}")
+            # logger.info(f"Exported {len(tasks)} tasks to {filename}")
             return filename
         else:
-            logger.info("No tasks found to export")
+            # logger.info("No tasks found to export")
             return None
 
     def import_single_task(self, task: Task, project_key: Optional[str] = None):
@@ -670,7 +670,7 @@ class Fleet:
             )
             return response
         except Exception as e:
-            logger.error(f"Failed to import task {task.key}: {e}")
+            # logger.error(f"Failed to import task {task.key}: {e}")
             return None
 
     def import_tasks(self, filename: str, project_key: Optional[str] = None):
@@ -883,17 +883,17 @@ def _execute_verifier_remote(
         request_data["bundle"] = bundle_b64
 
     # Debug logging
-    logger.debug(
-        f"Sending verifier execute request: key={key}, sha256={bundle_sha[:8]}..., function_name={function_name}"
-    )
-    logger.debug(f"Request has bundle: {needs_upload}")
-    logger.debug(f"Using client with base_url: {client.base_url}")
-    logger.debug(f"Request data keys: {list(request_data.keys())}")
-    logger.debug(
-        f"Bundle size: {len(request_data.get('bundle', ''))} chars"
-        if "bundle" in request_data
-        else "No bundle"
-    )
+    # logger.debug(
+    #     f"Sending verifier execute request: key={key}, sha256={bundle_sha[:8]}..., function_name={function_name}"
+    # )
+    # logger.debug(f"Request has bundle: {needs_upload}")
+    # logger.debug(f"Using client with base_url: {client.base_url}")
+    # logger.debug(f"Request data keys: {list(request_data.keys())}")
+    # logger.debug(
+    #     f"Bundle size: {len(request_data.get('bundle', ''))} chars"
+    #     if "bundle" in request_data
+    #     else "No bundle"
+    # )
 
     # Note: This should be called on the instance URL, not the orchestrator
     # The instance has manager URLs for verifier execution
@@ -901,6 +901,6 @@ def _execute_verifier_remote(
 
     # Debug the response
     response_json = response.json()
-    logger.debug(f"Verifier execute response: {response_json}")
+    # logger.debug(f"Verifier execute response: {response_json}")
 
     return VerifiersExecuteResponse(**response_json)
